summaryrefslogtreecommitdiffstats
path: root/kbfxlib/common/kbfxconfig.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kbfxlib/common/kbfxconfig.cpp')
-rw-r--r--kbfxlib/common/kbfxconfig.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kbfxlib/common/kbfxconfig.cpp b/kbfxlib/common/kbfxconfig.cpp
index da83d47..0e1c8ee 100644
--- a/kbfxlib/common/kbfxconfig.cpp
+++ b/kbfxlib/common/kbfxconfig.cpp
@@ -208,7 +208,7 @@ void KbfxConfig::setThemeInfoDefault()
void KbfxConfig::setThemeDefault()
{
/* set default theme tqlayout configuration */
m_KbfxNormalButtonPath = m_KbfxNormalButtonPathDefault;
m_KbfxHoverButtonPath = m_KbfxHoverButtonPathDefault;
m_KbfxPressedButtonPath = m_KbfxPressedButtonPathDefault;
@@ -487,7 +487,7 @@ void KbfxConfig::readFontrc ( TQString & themePath, TQString & themeName, bool u
void KbfxConfig::readThemerc ( TQString &themePath, TQString &themeName, bool user_rc )
{
- /* if a new version use default theme tqlayout */
+ /* if a new version use default theme layout */
if ( m_KbfxGeneralVersion < m_KbfxGeneralVersionDefault )
{
themePath = m_SpinxThemeBasePathDefault;
@@ -525,7 +525,7 @@ void KbfxConfig::readThemerc ( TQString &themePath, TQString &themeName, bool us
setThemeDefault();
/* get some theme tqlayout settings from theme file or from theme section */
TQString _abs_path = "";
TQFileInfo * info = new TQFileInfo ( themePath + themeName + "/kbfxlayoutrc" );
TQFileInfo * info_theme = new TQFileInfo ( KbfxThemeRcDestination + "/" + themeName + "_layoutrc" );
@@ -618,7 +618,7 @@ void KbfxConfig::readThemerc ( TQString &themePath, TQString &themeName, bool us
m_commentMargine = layoutconfig->readNumEntry ( "CommentMargin",m_commentMargineDefault );
m_iconSize = layoutconfig->readNumEntry ( "IconSize",m_iconSizeDefault );
- kdDebug() << "Read default tqlayout settings for theme: "
+ kdDebug() << "Read default layout settings for theme: "
<< themeName
<< " from file: "
<< _abs_path
@@ -774,7 +774,7 @@ void KbfxConfig::writeThemerc ( TQString & themeName )
{
checkValues();
/* write tqlayout theme configuration from theme name */
KConfig *layoutconfig = new KConfig ( KbfxThemeRcDestination + "/" + themeName + "_layoutrc" );
layoutconfig->setGroup ( "KbfxButton" );
@@ -208,7 +208,7 @@ void KbfxConfig::setThemeInfoDefault()
void KbfxConfig::setThemeDefault()
{
- /* set default theme tqlayout configuration */
+ /* set default theme layout configuration */
m_KbfxNormalButtonPath = m_KbfxNormalButtonPathDefault;
m_KbfxHoverButtonPath = m_KbfxHoverButtonPathDefault;
@@ -525,7 +525,7 @@ void KbfxConfig::readThemerc ( TQString &themePath, TQString &themeName, bool us
setThemeDefault();
- /* get some theme tqlayout settings from theme file or from theme section */
+ /* get some theme layout settings from theme file or from theme section */
TQString _abs_path = "";
TQFileInfo * info = new TQFileInfo ( themePath + themeName + "/kbfxlayoutrc" );
@@ -774,7 +774,7 @@ void KbfxConfig::writeThemerc ( TQString & themeName )
{
checkValues();
- /* write tqlayout theme configuration from theme name */
+ /* write layout theme configuration from theme name */
KConfig *layoutconfig = new KConfig ( KbfxThemeRcDestination + "/" + themeName + "_layoutrc" );
layoutconfig->setGroup ( "KbfxButton" );